@@ -1,3 +1,4 @@
+#include "cpp11/R.hpp"
 #include "Polynomial.h"
 
 constexpr std::size_t ParBitCutOff = 160u;
@@ -9,7 +10,7 @@ constexpr std::size_t ParBitCutOff = 160u;
 // the future. In particular, they were targeted to the primary dev
 // machine (i.e. 2017 Mac i7 16GB). There could be a more general
 // method for obtaining these values that better suits any platform.
-// 
+//
 // These values were modified from what is suggested in:
 // "The Multiple Polynomial Quadratic Sieve" by Robert D. Silverman
 //
@@ -39,12 +40,12 @@ constexpr std::size_t ParBitCutOff = 160u;
 // with Pollard's Rho algorithm.
 
 // lm(MSize[10:11] ~ DigSize[10:11])
-// 
+//
 // Call:
 //     lm(formula = MSize[10:11] ~ DigSize[10:11])
-//     
+//
 //     Coefficients:
-//     (Intercept)  DigSize[10:11]  
+//     (Intercept)  DigSize[10:11]
 //        -2100.00           41.67
 //
 // ***********************************************************************
@@ -63,121 +64,139 @@ double GetIntervalSize(double nDig) {
 // The idea is that we are trying to minimize the size of myLogs, an essential
 // vector in the sieving section
 int GetVecMax(int maxBasePrime, int tempLenB, std::size_t nThreads) {
-    
+
     int vecMaxSize = std::min(static_cast<int>(((L1Cache + maxBasePrime - 1)
                                                     / L1Cache) * L1Cache),
                                                     2 * tempLenB);
     if (vecMaxSize < (2 * tempLenB)) {
         int myDiv = 1;
-        
-        for (; (vecMaxSize / myDiv) > (8 * L1Cache) && myDiv < L1Cache;)
+
+        for (; (vecMaxSize / myDiv) > (8 * L1Cache) && myDiv < L1Cache;) {
             myDiv *= 2;
-        
+        }
+
         if (myDiv == 1 && (vecMaxSize > (4 * L1Cache)) && nThreads > 1) {
             vecMaxSize = (4 * L1Cache);
         } else {
             const int baseVecMax = L1Cache / myDiv;
             int myMult = std::numeric_limits<int>::max();
             int myIndex = 0;
-            
+
             for (int i = myDiv; (i * baseVecMax) < (8 * L1Cache); ++i) {
                 vecMaxSize = i * baseVecMax;
-                
+
                 int tempMult = (maxBasePrime + vecMaxSize - 1) / vecMaxSize;
-                
+
                 if (tempMult < myMult) {
                     myMult = tempMult;
                     myIndex = i;
                 }
             }
-            
+
             vecMaxSize = myIndex * baseVecMax;
         }
     }
-    
+
     return vecMaxSize;
 }
 
 void QuadraticSieve(const mpz_class &myNum, std::vector<mpz_class> &factors,
                     std::size_t nThreads, bool bShowStats) {
-    
+
     const auto checkPoint0 = std::chrono::steady_clock::now();
     const std::size_t digCount = mpz_sizeinbase(myNum.get_mpz_t(), 10);
     const std::size_t bits = mpz_sizeinbase(myNum.get_mpz_t(), 2);
-    const bool IsParallel = (nThreads == 1 || bits < ParBitCutOff) ? false : true;
-    
+    const bool IsParallel = (
+        nThreads == 1 || bits < ParBitCutOff
+    ) ? false : true;
+
     const double lognum = bits / std::log2(std::exp(1.0));
     const double sqrLogLog = std::sqrt(lognum * std::log(lognum));
     const double dblDigCount = digCount;
     double fudge1 = -0.4;
     double LimB = std::exp((0.5 + fudge1) * sqrLogLog);
-    
-    const double dblMyTarget = std::ceil(125.9297462 * dblDigCount - 4.7601496
-                                             * std::pow(dblDigCount, 2.0) + 0.0794196
-                                             * std::pow(dblDigCount, 3.0) - 0.0001794
-                                             * std::pow(dblDigCount, 4.0) - 1196.9999);
-    
+
+    const double dblMyTarget = std::ceil(
+        125.9297462 * dblDigCount - 4.7601496 * std::pow(dblDigCount, 2.0) +
+        0.0794196 * std::pow(dblDigCount, 3.0) -
+        0.0001794 * std::pow(dblDigCount, 4.0) - 1196.9999
+    );
+
     std::size_t myTarget = static_cast<std::size_t>(dblMyTarget);
-    
+
     while (LimB < myTarget) {
         LimB = std::exp((0.5 + fudge1) * sqrLogLog);
         fudge1 += 0.001;
     }
-    
-    const std::vector<int> facBase = GetPrimesQuadRes(myNum, LimB, fudge1, sqrLogLog, myTarget);
+
+    const std::vector<int> facBase = GetPrimesQuadRes(
+        myNum, LimB, fudge1, sqrLogLog, myTarget
+    );
     const double dblLenB = GetIntervalSize(dblDigCount);
     unsigned long int LenB = dblLenB * 1000;
-    
+
     const std::size_t facSize = facBase.size();
     const int vecMaxSize = GetVecMax(facBase.back(), LenB, nThreads);
-    
-    if (vecMaxSize < static_cast<int>(2 * LenB)) {LenB = (vecMaxSize) * (1 + LenB / (vecMaxSize));}
+
+    if (vecMaxSize < static_cast<int>(2 * LenB)) {
+        LenB = (vecMaxSize) * (1 + LenB / (vecMaxSize));
+    }
+
     const int TwiceLenB = 2 * LenB;
-    
+
     // This array will be passed to solutionSeach.
     std::vector<mpz_class> mpzFacBase;
-    
+
     mpz_class Temp;
     Temp = myNum * 2;
     Temp = sqrt(Temp) * LenB;
-    
+
     const double fudge2 = (digCount < 45) ? 1.410 :
                           (digCount < 50) ? 1.440 :
-                          (digCount < 60) ? 1.505 : 
+                          (digCount < 60) ? 1.505 :
                           (digCount < 65) ? 1.520 : 1.540;
-    
-    const logType theCut = std::ceil(dblLogMult * fudge2 *
-                                     static_cast<double>(mpz_sizeinbase(Temp.get_mpz_t(), 10)));
+
+    const logType theCut = std::ceil(
+        dblLogMult * fudge2 *
+            static_cast<double>(mpz_sizeinbase(Temp.get_mpz_t(), 10))
+    );
     std::vector<logType> LnFB(facSize);
-    
+
     for (std::size_t i = 0; i < facSize; ++i) {
         mpzFacBase.push_back(facBase[i]);
-        LnFB[i] = std::floor(dblLogMult * std::log(static_cast<double>(facBase[i])));
+        LnFB[i] = std::floor(dblLogMult *
+            std::log(static_cast<double>(facBase[i])));
     }
-    
+
     Temp = sqrt(myNum) - LenB;
-    const int minPrime = static_cast<int>(mpz_sizeinbase(Temp.get_mpz_t(), 10) * 2);
-    const auto itLow = std::lower_bound(facBase.cbegin(), facBase.cend(), minPrime);
+    const int minPrime = static_cast<int>(
+        mpz_sizeinbase(Temp.get_mpz_t(), 10) * 2
+    );
+    const auto itLow = std::lower_bound(
+        facBase.cbegin(), facBase.cend(), minPrime
+    );
     const std::size_t strt = std::distance(facBase.cbegin(), itLow);
-    
-    const auto itUpper = std::lower_bound(facBase.cbegin(), facBase.cend(), vecMaxSize);
+
+    const auto itUpper = std::lower_bound(
+        facBase.cbegin(), facBase.cend(), vecMaxSize
+    );
     const std::size_t vecMaxStrt = std::distance(facBase.cbegin(), itUpper);
-    
+
     const std::vector<std::size_t> SieveDist = GetSieveDist(facBase, myNum);
     const int LowBound = -1 * static_cast<int>(LenB);
-    
+
     mpz_class NextPrime;
     mpz_mul_2exp(NextPrime.get_mpz_t(), myNum.get_mpz_t(), 1);
     NextPrime = sqrt(NextPrime);
     NextPrime /= LenB;
     NextPrime = sqrt(NextPrime);
-    
+
     if (cmp(NextPrime, facBase.back()) < 0)
         NextPrime = facBase.back();
-    
+
     Polynomial myPoly(facSize, bShowStats, myNum);
     bool xtraTime = true;
-    
+
     if (IsParallel) {
         myPoly.FactorParallel(SieveDist, facBase, LnFB, mpzFacBase, NextPrime,
                               myNum, LowBound, theCut, TwiceLenB, vecMaxSize,
@@ -188,7 +207,7 @@ void QuadraticSieve(const mpz_class &myNum, std::vector<mpz_class> &factors,
                                myNum, nThreads, checkPoint0);
             myPoly.MakeStatsFalse();
             if (bShowStats && cmp(factors[0], 0) == 0) {
-                RcppThread::Rcout << "|      Extra Time      |\n|--------------------|" << std::endl;
+                Rprintf("|      Extra Time      |\n|--------------------|\n");
                 xtraTime = false;
             }
         }
@@ -211,8 +230,8 @@ void QuadraticSieve(const mpz_class &myNum, std::vector<mpz_class> &factors,
 
         if (bShowStats && cmp(factors[0], 0) == 0 && xtraTime) {
             t0 = std::chrono::steady_clock::now();
-            RcppThread::Rcout << " Unsuccessful initial factorization... more smooths needed \n" << std::endl;
-            RcppThread::Rcout << "|     Extra Time     |\n|--------------------|" << std::endl;
+            Rprintf(" Unsuccessful initial factorization... more smooths needed \n\n");
+            Rprintf("|     Extra Time     |\n|--------------------|\n");
             xtraTime = false;
             bUpdateXtra = true;
         }
@@ -221,7 +240,7 @@ void QuadraticSieve(const mpz_class &myNum, std::vector<mpz_class> &factors,
             OneColumnStats(std::chrono::steady_clock::now() - t0);
 
             if (cmp(factors[0], 0) > 0) {
-                RcppThread::Rcout << "\n" << std::endl;
+                Rprintf("\n\n");
             }
         }
     }
